Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elasticsearch Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon Elasticsearch Service - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon Elasticsearch Service

Amazon Elasticsearch Service (service prefix: `es` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

Topics

- Actions Defined by Amazon Elasticsearch Service
- Resource Types Defined by Amazon Elasticsearch Service
- Condition Keys for Amazon Elasticsearch Service

## Actions Defined by Amazon Elasticsearch Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AddTags | Grants permission to attach resource tags to an Amazon ES domain. | Tagging | domain* |  |
CreateElasticsearchDomain | Grants permission to create an Amazon ES domain. | Write | domain |  |
CreateElasticsearchServiceRole | Grants permission to create the service-linked role required for Amazon ES domains that use VPC access. | Write |  |  |
DeleteElasticsearchDomain | Grants permission to delete an Amazon ES domain and all of its data. | Write | domain* |  |
DeleteElasticsearchServiceRole | Grants permission to delete the service-linked role required for Amazon ES domains that use VPC access. | Write |  |  |
DescribeElasticsearchDomain | Grants permission to view a description of the domain configuration for the specified Amazon ES domain, including the domain ID, domain service endpoint, and domain ARN. | Read | domain* |  |
DescribeElasticsearchDomainConfig | Grants permission to view a description of the configuration options and status of an Amazon ES domain. | Read | domain* |  |
DescribeElasticsearchDomains | Grants permission to view a description of the domain configuration for up to five specified Amazon ES domains. | List | domain* |  |
DescribeElasticsearchInstanceTypeLimits | Grants permission to view the instance count, storage, and master node limits for a given Elasticsearch version and instance type. | List |  |  |
DescribeReservedElasticsearchInstanceOfferings | Grants permission to fetch reserved instance offerings for ES | List |  |  |
DescribeReservedElasticsearchInstances | Grants permission to fetch ES reserved instances already purchased by customer | List |  |  |
ESHttpDelete | Grants permission to send HTTP DELETE requests to the Elasticsearch APIs. | Write | domain |  |
ESHttpGet | Grants permission to send HTTP GET requests to the Elasticsearch APIs. | Read | domain |  |
ESHttpHead | Grants permission to send HTTP HEAD requests to the Elasticsearch APIs. | Read | domain |  |
ESHttpPatch | Grants permission to send HTTP PATCH requests to the Elasticsearch APIs. | Write | domain |  |
ESHttpPost | Grants permission to send HTTP POST requests to the Elasticsearch APIs. | Write | domain |  |
ESHttpPut | Grants permission to send HTTP PUT requests to the Elasticsearch APIs. | Write | domain |  |
GetCompatibleElasticsearchVersions | Grants permission to fetch list of compatible elastic search versions to which Amazon ES domain can be upgraded | List | domain* |  |
GetUpgradeHistory | Grants permission to fetch upgrade history for given ES domain | Read | domain* |  |
GetUpgradeStatus | Grants permission to fetch upgrade status for given ES domain | Read | domain* |  |
ListDomainNames | Grants permission to display the names of all Amazon ES domains that the current user owns. | List |  |  |
ListElasticsearchInstanceTypeDetails | Grants permission to list all instance types and available features for a given Elasticsearch version. | List |  |  |
ListElasticsearchInstanceTypes | Grants permission to list all Elasticsearch instance types that are supported for a given Elasticsearch version. | List |  |  |
ListElasticsearchVersions | Grants permission to list all supported Elasticsearch versions on Amazon ES. | List |  |  |
ListTags | Grants permission to display all of the tags for an Amazon ES domain. | Read | domain* |  |
PurchaseReservedElasticsearchInstanceOffering | Grants permission to purchase ES reserved instances | Write |  |  |
RemoveTags | Grants permission to remove tags from Amazon ES domains. | Tagging | domain* |  |
UpdateElasticsearchDomainConfig | Grants permission to modify the configuration of an Amazon ES domain, such as the instance type or number of instances. | Write | domain* |  |
UpgradeElasticsearchDomain | Grants permission to initiate upgrade of elastic search domain to given version | Write | domain* |  |

## Resource Types Defined by Amazon Elasticsearch Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
domain | `arn:$ { Partition}:es:$ { Region}:$ { Account}:domain/$ { DomainName}` |

## Condition Keys for Amazon Elasticsearch Service

Elasticsearch Service has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .